@@ -3,7 +3,7 @@ package Locale::TextDomain::OO; ## no critic (TidyCode)
 use strict;
 use warnings;
 
-our $VERSION = '1.025';
+our $VERSION = '1.026';
 
 use Locale::TextDomain::OO::Translator;
 
@@ -36,13 +36,13 @@ __END__
 
 Locale::TextDomain::OO - Perl OO Interface to Uniforum Message Translation
 
-$Id: OO.pm 633 2017-02-17 17:50:25Z steffenw $
+$Id: OO.pm 637 2017-02-23 16:21:35Z steffenw $
 
 $HeadURL: svn+ssh://steffenw@svn.code.sf.net/p/perl-gettext-oo/code/module/trunk/lib/Locale/TextDomain/OO.pm $
 
 =head1 VERSION
 
-1.025
+1.026
 
 Starting with version 1.000 the interface has changed.
 
@@ -64,14 +64,15 @@ like L<Locale::Maketext|Locale::Maketext>.
 You decide what you need.
 
 There are some plugins, so it is possible
-to use the Maketext and/or Gettext style.
+to use different the Maketext and/or Gettext styles.
 
 Locale::TextDomain::OO has a flexible object oriented interface
 based on L<Moo|Moo>.
 
 Creating the Lexicon and translating are two split things.
-So it is possible to create the lexicon during the initialization phase.
-The connection between both is the singleton mechanism of the lexicon module.
+So it is possible to create the lexicon during the compilation phase.
+The connection between both is the singleton mechanism
+of the lexicon module using  and L<MooX::Singleton|MooX::Singleton>.
 
 =head2 Plugin for the web framework?
 
@@ -95,7 +96,7 @@ We also added our project specific methods there.
 
 Write you own role. There is no need for a plugin for any framework.
 
-=head2 Who is setting the languages?
+=head2 Who to set the languages?
 
 Not this module.
 
@@ -110,6 +111,8 @@ This module will find the first match.
 Or you store and get the language in the session.
 
 Or your application has a language selection menu.
+(Never use flags for that.
+There are multilanguage countries and more countries have the same language.)
 
 =head2 How to extract the project files?
 
@@ -167,6 +170,17 @@ Gettext allows as much as needed plural forms at destination language.
 
 =item *
 
+Maketext has a plural formula as placeholder in strings to translate.
+Gettext has fully readable strings with simple placeholders.
+Then a very good automatic translation is possible and this module helps you.
+
+(Some projects have keywords instead of English language in code.
+This module helps you to write readable, uncrypic code.
+Programmers optimisation is a very bad idea for translations.
+Never split a sentence.)
+
+=item *
+
 'quant' inside a phrase is the end of the automatic translation
 because quant is an 'or'-construct.
 
@@ -282,10 +296,10 @@ Run the examples of this distribution (folder example).
  | data      |   |           |   `----------' |-.   `----------' |-.    |
  | structure |   | Database  |     `----------' |     `----------' |    |
  `-----------'   `-----------'       `----------'       `----------'    |
-                                       ^  ^               ^             |
-                                       |  |               |             |
-         .-----------------------------'  |               |             |
-  _______|_______                         |               |             |
+       ^                               ^   ^              ^             |
+       |                               |   |              |             |
+       |   .---------------------------'   |              |             |
+  _____|___|_____                          |              |             |
  /_ _ _ _ _ _ _ _\   .----------------------------------------------.   |
  | Autotranslate |   | build using PO/MO                            |   |
  | Cache         |   | Locale::TextDomain::OO::Extract              |   |
@@ -378,7 +392,7 @@ Instead of method new call method instance to get a singleton.
     );
     $same_instance = Locale::TextDomain::OO->instance;
 
-=head2 Attributes handled with plugin Expand::Gettext::Loc
+=head2 Attributes handled e.g. with plugin Expand::Gettext::Loc
 
 This plugin can handle named placeholders like C<{name}>.
 For numeric placeholders add attribute C<:num>.
