@@ -7,7 +7,7 @@ use Moo;
 use MooX::StrictConstructor;
 use namespace::autoclean;
 
-our $VERSION = '1.007';
+our $VERSION = '1.026';
 
 with qw(
     Locale::TextDomain::OO::Lexicon::Role::File
@@ -36,7 +36,7 @@ $HeadURL: svn+ssh://steffenw@svn.code.sf.net/p/perl-gettext-oo/code/module/trunk
 
 =head1 VERSION
 
-1.007
+1.026
 
 =head1 DESCRIPTION
 
@@ -98,6 +98,10 @@ This module reads a gettext mo file into the lexicon.
 
 =head1 SUBROUTINES/METHODS
 
+=head2 method new
+
+see SYNOPSIS
+
 =head2 method lexicon_ref
 
 See SYNOPSIS.
