@@ -8,7 +8,7 @@ use Moo;
 use MooX::StrictConstructor;
 use namespace::autoclean;
 
-our $VERSION = '1.014';
+our $VERSION = '1.026';
 
 with qw(
     Locale::TextDomain::OO::Lexicon::Role::File
@@ -64,7 +64,7 @@ $HeadURL: svn+ssh://steffenw@svn.code.sf.net/p/perl-gettext-oo/code/module/trunk
 
 =head1 VERSION
 
-1.014
+1.026
 
 =head1 DESCRIPTION
 
@@ -126,6 +126,10 @@ This module reads a gettext po file into the lexicon.
 
 =head1 SUBROUTINES/METHODS
 
+=head2 method new
+
+see SYNOPSIS
+
 =head2 method lexicon_ref
 
 See SYNOPSIS.
