@@ -10,7 +10,7 @@ use Moo;
 use MooX::StrictConstructor;
 use namespace::autoclean;
 
-our $VERSION = '1.023';
+our $VERSION = '1.026';
 
 with qw(
     Locale::TextDomain::OO::Role::Logger
@@ -79,7 +79,7 @@ $HeadURL: svn+ssh://steffenw@svn.code.sf.net/p/perl-gettext-oo/code/module/trunk
 
 =head1 VERSION
 
-1.023
+1.026
 
 =head1 DESCRIPTION
 
@@ -103,6 +103,10 @@ This module allows to create a lexicon from data structure.
 
 =head1 SUBROUTINES/METHODS
 
+=head2 method new
+
+see SYNOPSIS
+
 =head2 method lexicon_ref
 
 Fill in lexicon data from Perl data structure.
