@@ -7,7 +7,7 @@ use Moo;
 use MooX::StrictConstructor;
 use namespace::autoclean;
 
-our $VERSION = '1.022';
+our $VERSION = '1.026';
 
 with qw(
     Locale::TextDomain::OO::Lexicon::Role::StoreFile
@@ -60,7 +60,7 @@ $HeadURL: svn+ssh://steffenw@svn.code.sf.net/p/perl-gettext-oo/code/module/trunk
 
 =head1 VERSION
 
-1.022
+1.026
 
 =head1 DESCRIPTION
 
@@ -142,6 +142,10 @@ This module stores the lexicon for other programming language e.g. JavaScript.
 
 =head1 SUBROUTINES/METHODS
 
+=head2 method new
+
+see SYNOPSIS
+
 =head2 method to_json
 
 With file parameters it prints a JSON file.
