@@ -11,7 +11,7 @@ use MooX::StrictConstructor;
 use MooX::Types::MooseLike::Base qw(Str);
 use namespace::autoclean;
 
-our $VERSION = '1.025';
+our $VERSION = '1.026';
 
 with qw(
     Locale::TextDomain::OO::Role::Logger
@@ -271,13 +271,13 @@ __END__
 
 Locale::TextDomain::OO::Translator - Translator class
 
-$Id: Translator.pm 633 2017-02-17 17:50:25Z steffenw $
+$Id: Translator.pm 637 2017-02-23 16:21:35Z steffenw $
 
 $HeadURL: svn+ssh://steffenw@svn.code.sf.net/p/perl-gettext-oo/code/module/trunk/lib/Locale/TextDomain/OO/Translator.pm $
 
 =head1 VERSION
 
-1.025
+1.026
 
 =head1 DESCRIPTION
 
@@ -292,6 +292,10 @@ This is the translator class. Extend that class with plugins (Roles).
 
 =head1 SUBROUTINES/METHODS
 
+=head2 method new
+
+see SYNOPSIS
+
 =head2 class method load_plugins
 
 Called before new to load the plugins.
